(goto-char (point-min))
(when (re-search-forward "^@setfilename.*$")
  (replace-match "@setfilename mew.info"))

(goto-char (point-min))
(when (re-search-forward "^@set jp$")
  (replace-match "@set us"))

(goto-char (point-min))
(when (search-forward "**end of header")
  (forward-line 1)
  (beginning-of-line)
  (insert "@direntry\n")
  (insert "* Mew::                           Messaging in the Emacs World\n")
  (insert "@end direntry\n"))
