(goto-char (point-min))
(when (re-search-forward "^@setfilename.*$")
  (replace-match "@setfilename mew.jis.info"))

(goto-char (point-min))
(when (search-forward "**end of header")
  (forward-line 1)
  (beginning-of-line)
  (insert "@direntry\n")
  (insert "* Mew: (mew.jis)                  Messaging in the Emacs World(日本語版)\n")
  (insert "@end direntry\n"))
